-- ############################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  5724-B96
-- #
-- #  (C) Copyright IBM Corp. 2003.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #   File Information: src/tedw_apps_etl/ctw/pkg/v110/cdw/dml/ctw_cdw_data.sql
-- #   Revision: 1.22
-- #   Date: 2/5/03 19:55:12
-- ############################################################################

----------------------------
-- File Name: ctw_cdw_dml.sql
-- Author: Tivoli
---------------------------
-- create a temporary table for measurement source cd

declare global temporary table MSrc (
       MSrc_Cd              CHAR(6) NOT NULL,
       MSrc_Parent_Cd       CHAR(6) NOT NULL,
       MSrc_Nm              VARCHAR(120) NOT NULL
) with replace on commit preserve rows not logged ;

insert into session.MSrc
  values ('CTW', 'AMX', 'IBM Tivoli Monitoring for Databases, Version 5.1.0: Microsoft SQL Server');

insert into TWG.MSrc
   select m.MSrc_Cd,
          m.MSrc_Parent_Cd,
          m.MSrc_Nm
     from session.MSrc m
    where not exists ( select 1 from TWG.MSrc t
                         where t.MSrc_Cd=m.MSrc_Cd )
;

-- create a temporary table for Microsoft SQL Server component types
-- and the server generic type

declare global temporary table MSSQL_CompTyp (
       CompTyp_Cd           CHAR(17) NOT NULL,
       CompTyp_Parent_Cd    CHAR(17),
       CompTyp_Nm           VARCHAR(120) NOT NULL,
       CompTyp_Strt_DtTm    TIMESTAMP NOT NULL,
       CompTyp_End_DtTm     TIMESTAMP NOT NULL
) with replace on commit preserve rows not logged ;

insert into session.MSSQL_CompTyp values ('IP_HOST', null, 'Microsoft SQL Server', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.MSSQL_CompTyp values ('CTW_HOST',null, 'Microsoft SQL Server Host', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.MSSQL_CompTyp values ('CTW_INSTANCE',null, 'Microsoft SQL Server Instance', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.MSSQL_CompTyp values ('CTW_DATABASE',null, 'Microsoft SQL Server Database',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.MSSQL_CompTyp values ('CTW_FILEGROUP',null, 'Microsoft SQL Server Database Filegroup', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.MSSQL_CompTyp values ('CTW_REPLICATION',null, 'Microsoft SQL Server Database Replication', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.MSSQL_CompTyp values ('CTW_JOBCATEGORY',null, 'Microsoft SQL Server Job Category', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.MSSQL_CompTyp values ('CTW_SERVICE',null, 'Microsoft SQL Server NT Service', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.MSSQL_CompTyp values ('CTW_AGENT',null, 'Microsoft SQL Server Agent', current timestamp - current timezone, '9999-01-01-00.00.00.000000');

-- insert the Microsoft SQL Server component types into the generic schema
-- if not exist already

insert into TWG.CompTyp
   select c.CompTyp_Cd,
          c.CompTyp_Parent_Cd,
          c.CompTyp_Nm,
          c.CompTyp_Strt_DtTm,
          c.CompTyp_End_DtTm
     from session.MSSQL_CompTyp c
    where not exists ( select 1 from TWG.Cur_CompTyp t
                        where t.CompTyp_cd=c.CompTyp_cd)
;
--
--  Insert Relation Rule default data
--
declare global temporary table RelnRul (
        CompTyp_Source_CD       CHAR(17) NOT NULL,
        CompTyp_Target_CD       CHAR(17) NOT NULL,
        RelnTyp_CD              CHAR(6) NOT NULL,
        RelnRul_Strt_DtTm       TIMESTAMP NOT NULL,
        RelnRul_End_DtTm        TIMESTAMP NOT NULL
) with replace on commit preserve rows not logged ;

insert into session.RelnRul values ('IP_HOST','CTW_SERVICE','PCHILD', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.RelnRul values ('IP_HOST','CTW_INSTANCE','PCHILD', current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.RelnRul values ('CTW_HOST','CTW_INSTANCE','PCHILD', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.RelnRul values ('CTW_HOST','CTW_SERVICE','PCHILD', current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.RelnRul values ('IP_INTERFACE','CTW_SERVICE','PCHILD', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.RelnRul values ('IP_INTERFACE','CTW_INSTANCE','PCHILD', current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.RelnRul values ('CTW_INSTANCE','CTW_DATABASE','PCHILD', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.RelnRul values ('CTW_INSTANCE','CTW_JOBCATEGORY','PCHILD', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.RelnRul values ('CTW_INSTANCE','CTW_REPLICATION','PCHILD', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.RelnRul values ('CTW_INSTANCE','CTW_AGENT','PCHILD', current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.RelnRul values ('CTW_DATABASE','CTW_FILEGROUP','PCHILD', current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into TWG.RelnRul
   SELECT m.CompTyp_Source_Cd as CompTyp_Source_Cd,
          m.CompTyp_Target_Cd as CompTyp_Target_Cd,
          m.RelnTyp_Cd as RelnTyp_Cd,
          m.RelnRul_Strt_DtTm as RelnRul_Strt_DtTm,
          m.RelnRul_End_DtTm as RelnRul_End_DtTm
     FROM session.RelnRul m
    WHERE not EXISTS ( select 1 FROM TWG.RelnRul t
                        WHERE t.CompTyp_Source_Cd = m.CompTyp_Source_Cd
                          AND t.CompTyp_Target_Cd = m.CompTyp_Target_Cd
                          AND t.RelnTyp_Cd = m.RelnTyp_Cd )
;

--
--  Insert Attribute Type default data
--
declare global temporary table attrtyp (
        AttrTyp_Cd           CHAR(17) NOT NULL,
        AttrTyp_Nm           VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged ;

insert into session.AttrTyp values ('MAX_CONNECTIONS','Maximum connections to database instance');
insert into session.AttrTyp values ('CTW_LOG_FILENAME','Database log file names');
insert into session.AttrTyp values ('CTW_LOG_MAXSIZE','Maximum aize of satabase log file');
insert into session.AttrTyp values ('CTW_FILEG_MAXSIZE','Maximum size of filegroup');
insert into session.AttrTyp values ('CTW_DB_MAXSIZE','Maximum size of database');

insert into twg.attrtyp (ATTRTYP_CD, ATTRTYP_NM)
   select * from session.attrtyp s
     where not exists ( select 1 from twg.attrtyp t
                           where t.attrtyp_cd = s.attrtyp_cd )
;
--
--  Insert Attribute Rule Data
--
declare global temporary table attrrul (
       CompTyp_Cd           CHAR(17) NOT NULL,
       AttrTyp_Cd           CHAR(17) NOT NULL,
       AttrRul_Strt_DtTm    TIMESTAMP NOT NULL,
       AttrRul_End_DtTm     TIMESTAMP NOT NULL,
       AttrRul_Dom_Ind      CHAR NOT NULL
) with replace on commit preserve rows not logged ;

insert into session.AttrRul values('CTW_INSTANCE','VERSION',current timestamp - current timezone, '9999-01-01-00.00.00.000000', 'N');
insert into session.AttrRul values('CTW_INSTANCE','NAME',current timestamp - current timezone, '9999-01-01-00.00.00.000000', 'N');
insert into session.AttrRul values('CTW_HOST','AMX_EID',current timestamp - current timezone, '9999-01-01-00.00.00.000000', 'N');
insert into session.AttrRul values('CTW_HOST','AMX_GMT_OFFSET',current timestamp - current timezone, '9999-01-01-00.00.00.000000', 'N');
insert into session.AttrRul values('CTW_INSTANCE','MAX_CONNECTIONS',current timestamp - current timezone, '9999-01-01-00.00.00.000000', 'N');
insert into session.AttrRul values('CTW_FILEGROUP','CTW_FILEG_MAXSIZE',current timestamp - current timezone, '9999-01-01-00.00.00.000000', 'N');
insert into session.AttrRul values('CTW_DATABASE','CTW_DB_MAXSIZE',current timestamp - current timezone, '9999-01-01-00.00.00.000000', 'N');
insert into session.AttrRul values('CTW_DATABASE','CTW_LOG_MAXSIZE',current timestamp - current timezone, '9999-01-01-00.00.00.000000', 'N');
insert into session.AttrRul values('CTW_DATABASE','CTW_LOG_FILENAME',current timestamp - current timezone, '9999-01-01-00.00.00.000000', 'N');

insert into twg.attrrul (COMPTYP_CD, ATTRTYP_CD, ATTRRUL_STRT_DTTM,
                          ATTRRUL_END_DTTM, ATTRRUL_DOM_IND)
   select * from session.attrrul s
      where not exists ( select 1 from twg.attrrul t
                           where t.comptyp_cd = s.comptyp_cd
                             and t.attrtyp_cd = s.attrtyp_cd )
;
-- create a temporary table for Microsoft SQL Server measurement types
declare global temporary table MSSQL_MsmtTyp (
       MUnit_Cd      CHAR(6) NOT NULL,
       MSrc_Cd       CHAR(6) NOT NULL,
       MsmtTyp_Nm    VARCHAR(120) NOT NULL,
       MsmtTyp_Ds    VARCHAR(254)
) with replace on commit preserve rows not logged;

insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC','CTW','MSSQL_Service_Stopped','SQL Server Service in stopped state');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC','CTW','MSSQL_Service_Paused','SQL Server Service in paused state');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC','CTW','MSSQL_Service_Running','SQL Server Service in running state');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Qps','CTW','MSSQL_Logouts','The number of logouts per second');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Qps','CTW','MSSQL_Logins','The number of logins per second');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_User_Connections','The number of users logged into server');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC','CTW','MSSQL_Percent_User_Connections_Used','Percentage of maximum connections used');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Active_Transactions','The number of active transactions in server');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Qps','CTW','MSSQL_Transactions_Rate','The number of transactions per second');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Blocked_Processes','The number of processes blocked');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC','CTW','MSSQL_Buffer_Cache_Hit_Ratio','Buffer requests satisfied from cache');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC','CTW','MSSQL_Buffer_Extended_Memory_Cache_Hit_Ratio','Buffer requests satisfied from extended memory');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Free_Buffers','Number of free buffers');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Qps','CTW','MSSQL_Lazy_Writes','Dirty/Aged buffers written by Lazy Writer per second');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Qps','CTW','MSSQL_Page_Writes','Number of physical writes to database per second');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Qps','CTW','MSSQL_Page_Reads','Number of physical reads to database per second');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Qps','CTW','MSSQL_Read_Ahead_Pages','Anticipated reads by server');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Stolen_Page_Count','Number of pages used for server processes');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Stolen_Page_Count_Growth','Increase in  stolen pages per cycle');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Qps','CTW','MSSQL_Checkpoint_Writes','Number of database checkpoints per second');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Server_Memory_Used','Total memory used by server');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC','CTW','MSSQL_CPU_Percent_Busy','Percent CPU has been doing SQL Server work');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Number_Deadlocks','The number of deadlocks');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Job_Failed','Number of jobs failed');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Job_Succeeded','Number of jobs succeeded');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Job_Cancelled','Number of jobs cancelled');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Job_Retry','Number of jobs retried');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Job_In_Progress','Number of jobs running');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Job_Not_Run','Number of jobs not run');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Sec','CTW','MSSQL_Job_Duration','Number of seconds job run');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC','CTW','MSSQL_Database_Online','Percent database state is online');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC','CTW','MSSQL_Database_Suspect','Percent database state is suspect');


-- not logging, may use at later date JerryW 03/12/2003
-- insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Disk_IO_Errors','The number of disk I/O errors');
-- insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Space_Allocation_Failure','The number of times space allocation failed');

-- not logging, using lock wait time instead JerryW 03/12/2003
-- insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Qps','CTW','MSSQL_Lock_Waits','The number of detected locks');

insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Qps','CTW','MSSQL_Lock_Requests','The number of lock requests');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Qps','CTW','MSSQL_Lock_Timeouts','Lock wait timeouts');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Sec','CTW','MSSQL_Lock_Wait_Time','Time waiting for lock');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Qps','CTW','MSSQL_Table_Lock_Escalations','The number of locks escalated');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Replication_Pending_Transactions','The total number of pending transactions to be run');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Qps','CTW','MSSQL_Replication_Transaction_Rate','The total number of pending transactions per second');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Sec','CTW','MSSQL_Delivery_Latency','The average transaction latency');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Qps','CTW','MSSQL_Delivered_Commands','The number of commands per second');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Qps','CTW','MSSQL_Delivered_Transactions','The number of transactions per second');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Qps','CTW','MSSQL_Conflicts','The number of conflicts per second');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Qps','CTW','MSSQL_Uploaded_Changes','The number of upload changes per second');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Qps','CTW','MSSQL_Downloaded_Changes','The number of download changes per second');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MB','CTW','MSSQL_Log_File_Size','Size of log file');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC','CTW','MSSQL_Log_Space_Percent_Used_Actual','Percent of maximum log space used');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC','CTW','MSSQL_Database_Size','Size of database');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC','CTW','MSSQL_Database_Space_Percent_Used_Actual','Percent of maximum database used');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC','CTW','MSSQL_Database_Growth_Percent_Actual','Percent database grew  this cycle');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC','CTW','MSSQL_Filegroup_Space_Percent_Used_Actual','Filegroup space percent used');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MB','CTW','MSSQL_Filegroup_Size','Current size of Filegroup');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Replication_Job_Failed','Number of jobs failed');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Replication_Job_Between_Retries','Number of jobs between retries');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Replication_Job_Retry','Number of jobs retried');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Replication_Job_Idle','Number of jobs idle');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Replication_Job_In_Progress','Number of jobs in progress');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Replication_Job_Cancelled','Number of jobs cancelled');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Replication_Job_Waiting_For_Thread','Number of jobs waiting for thread');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Replication_Job_Succeeded','Number of jobs succeeded');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Replication_Job_Executing','Number of jobs executing');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Replication_Job_Suspended','Number of jobs suspended');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Replication_Job_Performing_Completion_Actions','Number of jobs performing completion actions');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Error_Count_Transaction_Log_Full','Number of times Transaction Log Full message in error log');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Error_Count_Disk_IO_Errors','Number of times Disk I/O Error message in error log');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Error_Count_Connections_High','Number of times Connections High message in error log');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Error_Count_Connections_Failed','Number of times Connection Failed message in error log');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Error_Count_Allocate_Space_Failed','Number of times Allocate Failed message in error log');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Error_Count_Transaction_Log_Errors','Number of times Transaction Log Error message in error log');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Error_Count_Database_Full','Number of times Database Full message in error log');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Error_Count_Deadlock_Alert','Number of times Deadlock Alert message in error log');
insert into session.MSSQL_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY','CTW','MSSQL_Error_Count_Customer_Defined','Number of times Customer Defined message in error log');

-- insert the Microsoft SQL Server measurement types into the generic schema
-- if not exist already

insert into TWG.MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds)
   SELECT m.MUnit_Cd,
          m.MSrc_Cd,
          m.MsmtTyp_Nm,
          m.MsmtTyp_Ds
     FROM session.MSSQL_MsmtTyp m
    where not EXISTS ( select 1 FROM TWG.MsmtTyp t
                         WHERE t.MsmtTyp_Nm=m.MsmtTyp_Nm );

-- create a temporary table for Microsoft SQL Server measurement types
declare global temporary table MSSQL_MsmtRul (
       CompTyp_Cd           CHAR(17) NOT NULL,
       MsmtTyp_ID           INTEGER NOT NULL )
   with replace on commit preserve rows not logged;

insert into session.MSSQL_MsmtRul
   select 'CTW_SERVICE', mt.MsmtTyp_ID from TWG.MsmtTyp mt
   where MsmtTyp_Nm in ( 'MSSQL_Service_Stopped',
                         'MSSQL_Service_Paused',
                         'MSSQL_Service_Running' );

insert into session.MSSQL_MsmtRul
   select 'CTW_INSTANCE', mt.MsmtTyp_ID from TWG.MsmtTyp mt
   where MsmtTyp_Nm in ( 'MSSQL_Logouts',
                         'MSSQL_Logins',
                         'MSSQL_User_Connections',
                         'MSSQL_Percent_User_Connections_Used',
                         'MSSQL_Blocked_Processes',
                         'MSSQL_Buffer_Cache_Hit_Ratio',
                         'MSSQL_Buffer_Extended_Memory_Cache_Hit_Ratio',
                         'MSSQL_Free_Buffers',
                         'MSSQL_Lazy_Writes',
                         'MSSQL_Page_Writes',
                         'MSSQL_Page_Reads',
                         'MSSQL_Read_Ahead_Pages',
                         'MSSQL_Stolen_Page_Count',
                         'MSSQL_Stolen_Page_Count_Growth',
                         'MSSQL_Checkpoint_Writes',
                         'MSSQL_Server_Memory_Used',
                         'MSSQL_CPU_Percent_Busy',
                         'MSSQL_Number_Deadlocks',
                         'MSSQL_Disk_IO_Errors',
                         'MSSQL_Space_Allocation_Failure',
                         'MSSQL_Lock_Waits',
                         'MSSQL_Lock_Requests',
                         'MSSQL_Lock_Timeouts',
                         'MSSQL_Lock_Wait_Time',
                         'MSSQL_Table_Lock_Escalations',
                         'MSSQL_Error_Count_Transaction_Log_Full',
                         'MSSQL_Error_Count_Disk_IO_Errors',
                         'MSSQL_Error_Count_Connections_High',
                         'MSSQL_Error_Count_Connections_Failed',
                         'MSSQL_Error_Count_Allocate_Space_Failed',
                         'MSSQL_Error_Count_Transaction_Log_Errors',
                         'MSSQL_Error_Count_Database_Full',
                         'MSSQL_Error_Count_Deadlock_Alert',
                         'MSSQL_Error_Count_Customer_Defined');

insert into session.MSSQL_MsmtRul
   select 'CTW_JOBCATEGORY', mt.MsmtTyp_ID from TWG.MsmtTyp mt
   where MsmtTyp_Nm in ( 'MSSQL_Job_Failed',
                         'MSSQL_Job_Succeeded',
                         'MSSQL_Job_Cancelled',
                         'MSSQL_Job_Retry',
                         'MSSQL_Job_In_Progress',
                         'MSSQL_Job_Not_Run',
                         'MSSQL_Job_Duration',
                         'MSSQL_Replication_Job_Failed',
                         'MSSQL_Replication_Job_Between_Retries',
                         'MSSQL_Replication_Job_Retry',
                         'MSSQL_Replication_Job_Idle',
                         'MSSQL_Replication_Job_In_Progress',
                         'MSSQL_Replication_Job_Cancelled',
                         'MSSQL_Replication_Job_Waiting_For_Thread',
                         'MSSQL_Replication_Job_Succeeded',
                         'MSSQL_Replication_Job_Executing',
                         'MSSQL_Replication_Job_Suspended',
                         'MSSQL_Replication_Job_Performing_Completion_Actions' );

insert into session.MSSQL_MsmtRul
   select 'CTW_DATABASE', mt.MsmtTyp_ID from TWG.MsmtTyp mt
   where MsmtTyp_Nm in ( 'MSSQL_Active_Transactions',
                         'MSSQL_Transactions_Rate',
                         'MSSQL_Database_Online',
                         'MSSQL_Database_Suspect',
                         'MSSQL_Log_File_Size',
                         'MSSQL_Log_Space_Percent_Used_Actual',
                         'MSSQL_Database_Size',
                         'MSSQL_Database_Space_Percent_Used_Actual',
                         'MSSQL_Database_Growth_Percent_Actual' );

insert into session.MSSQL_MsmtRul
   select 'CTW_FILEGROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt
   where MsmtTyp_Nm in ( 'MSSQL_Filegroup_Space_Percent_Used_Actual',
                         'MSSQL_Filegroup_Size');

insert into session.MSSQL_MsmtRul
   select 'CTW_AGENT', mt.MsmtTyp_ID from TWG.MsmtTyp mt
   where MsmtTyp_Nm in ( 'MSSQL_Delivery_Latency',
                         'MSSQL_Delivered_Commands',
                         'MSSQL_Delivered_Transactions',
                         'MSSQL_Conflicts',
                         'MSSQL_Uploaded_Changes',
                         'MSSQL_Downloaded_Changes' );

insert into session.MSSQL_MsmtRul
   select 'CTW_REPLICATION', mt.MsmtTyp_ID from TWG.MsmtTyp mt
   where MsmtTyp_Nm in ( 'MSSQL_Replication_Pending_Transactions',
                         'MSSQL_Replication_Transaction_Rate' );

-- insert the measurement rule into the generic schema
-- if not exist already

insert into TWG.MsmtRul (COMPTYP_CD, MSMTTYP_ID)
   select m.CompTyp_Cd,
          m.MsmtTyp_ID
     from session.MSSQL_MsmtRul m
    where not exists ( select 1 from TWG.MsmtRul t
                         where t.CompTyp_Cd=m.CompTyp_Cd
                           and t.MsmtTyp_ID=m.MsmtTyp_ID )
;
--
-- Insert measurement group type codes
--
declare global temporary table mgrptyp (
  MGrpTyp_Cd           CHAR(6) NOT NULL,
  MGrpTyp_Nm           VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.MgrpTyp values ('STATE','State');
insert into session.MgrpTyp values ('CATEG','Category');
insert into session.mgrptyp values ('GROUP', 'Aggregate Types or Group Functions');

insert into twg.mgrptyp
   select * from session.mgrptyp s
    where not exists ( select 1 from twg.mgrptyp t
                        where t.mgrptyp_Cd = s.mgrptyp_Cd )
;

--
-- create a temporary table for measurement group
--
declare global temporary table MGrp (
       MGrp_Cd              CHAR(6) NOT NULL,
       MGrpTyp_Cd           CHAR(6) NOT NULL,
       MGrp_Parent_Cd       CHAR(6),
       MGrp_Nm              VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.MGrp values ('CTW_SV','STATE',NULL,'Microsoft SQL Server Percent in State');
insert into session.MGrp values ('CTW_DB','STATE',NULL,'Microsoft SQL Server Database Percent in State');

insert into twg.mgrp
   select * from session.mgrp s
    where not exists ( select 1 from twg.mgrp t
                        where t.mgrp_Cd = s.mgrp_Cd )
;

--
--  Insert Group Member
--
-- create a temporary table for measurement group member

declare global temporary table MGrpMbr (
       MGrp_Cd              CHAR(6) NOT NULL,
       MGrpTyp_Cd           CHAR(6) NOT NULL,
       MsmtTyp_ID           INTEGER NOT NULL

) with replace on commit preserve rows not logged ;

insert into session.MGrpMbr
  select 'CTW_SV','STATE',mt.MsmtTyp_ID from TWG.MsmtTyp mt
   where MsmtTyp_Nm in ( 'MSSQL_Service_Stopped',
                         'MSSQL_Service_Paused',
                         'MSSQL_Service_Running' );

insert into session.MGrpMbr
   select 'CTW_DB','STATE',mt.MsmtTyp_ID from TWG.MsmtTyp mt
    where MsmtTyp_Nm in ( 'MSSQL_Database_Online',
                          'MSSQL_Database_Suspect' );

insert into session.MGrpMbr
   select 'AVG_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt
    where MsmtTyp_Nm in ('MSSQL_Service_Stopped',
                         'MSSQL_Service_Paused',
                         'MSSQL_Service_Running',
                         'MSSQL_Database_Online',
                         'MSSQL_Database_Suspect',
                         'MSSQL_Logouts',
                         'MSSQL_Logins',
                         'MSSQL_User_Connections',
                         'MSSQL_Percent_User_Connections_Used',
                         'MSSQL_Blocked_Processes',
                         'MSSQL_Buffer_Cache_Hit_Ratio',
                         'MSSQL_Buffer_Extended_Memory_Cache_Hit_Ratio',
                         'MSSQL_Free_Buffers',
                         'MSSQL_Lazy_Writes',
                         'MSSQL_Page_Writes',
                         'MSSQL_Page_Reads',
                         'MSSQL_Read_Ahead_Pages',
                         'MSSQL_Stolen_Page_Count',
                         'MSSQL_Stolen_Page_Count_Growth',
                         'MSSQL_Checkpoint_Writes',
                         'MSSQL_Server_Memory_Used',
                         'MSSQL_CPU_Percent_Busy',
                         'MSSQL_Number_Deadlocks',
                         'MSSQL_Disk_IO_Errors',
                         'MSSQL_Space_Allocation_Failure',
                         'MSSQL_Lock_Waits',
                         'MSSQL_Lock_Requests',
                         'MSSQL_Lock_Timeouts',
                         'MSSQL_Lock_Wait_Time',
                         'MSSQL_Table_Lock_Escalations',
                         'MSSQL_Replication_Pending_Transactions',
                         'MSSQL_Replication_Transaction_Rate',
                         'MSSQL_Delivery_Latency',
                         'MSSQL_Delivered_Commands',
                         'MSSQL_Delivered_Transactions',
                         'MSSQL_Conflicts',
                         'MSSQL_Uploaded_Changes',
                         'MSSQL_Downloaded_Changes',
                         'MSSQL_Active_Transactions',
                         'MSSQL_Transactions_Rate',
                         'MSSQL_Log_File_Size',
                         'MSSQL_Log_Space_Percent_Used_Actual',
                         'MSSQL_Database_Size',
                         'MSSQL_Database_Space_Percent_Used_Actual',
                         'MSSQL_Database_Growth_Percent_Actual',
                         'MSSQL_Filegroup_Space_Percent_Used_Actual',
                         'MSSQL_Filegroup_Size',
                         'MSSQL_Error_Count_Transaction_Log_Full',
                         'MSSQL_Error_Count_Disk_IO_Errors',
                         'MSSQL_Error_Count_Connections_High',
                         'MSSQL_Error_Count_Connections_Failed',
                         'MSSQL_Error_Count_Allocate_Space_Failed',
                         'MSSQL_Error_Count_Transaction_Log_Errors',
                         'MSSQL_Error_Count_Database_Full',
                         'MSSQL_Error_Count_Deadlock_Alert',
                         'MSSQL_Error_Count_Customer_Defined');

insert into session.MGrpMbr
  select 'MAX_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt
    where MsmtTyp_Nm in ('MSSQL_Service_Stopped',
                         'MSSQL_Service_Paused',
                         'MSSQL_Service_Running',
                         'MSSQL_Database_Online',
                         'MSSQL_Database_Suspect',
                         'MSSQL_Logouts',
                         'MSSQL_Logins',
                         'MSSQL_User_Connections',
                         'MSSQL_Percent_User_Connections_Used',
                         'MSSQL_Blocked_Processes',
                         'MSSQL_Buffer_Cache_Hit_Ratio',
                         'MSSQL_Buffer_Extended_Memory_Cache_Hit_Ratio',
                         'MSSQL_Free_Buffers',
                         'MSSQL_Lazy_Writes',
                         'MSSQL_Page_Writes',
                         'MSSQL_Page_Reads',
                         'MSSQL_Read_Ahead_Pages',
                         'MSSQL_Stolen_Page_Count',
                         'MSSQL_Stolen_Page_Count_Growth',
                         'MSSQL_Checkpoint_Writes',
                         'MSSQL_Server_Memory_Used',
                         'MSSQL_CPU_Percent_Busy',
                         'MSSQL_Number_Deadlocks',
                         'MSSQL_Disk_IO_Errors',
                         'MSSQL_Space_Allocation_Failure',
                         'MSSQL_Lock_Waits',
                         'MSSQL_Lock_Requests',
                         'MSSQL_Lock_Timeouts',
                         'MSSQL_Lock_Wait_Time',
                         'MSSQL_Table_Lock_Escalations',
                         'MSSQL_Replication_Pending_Transactions',
                         'MSSQL_Replication_Transaction_Rate',
                         'MSSQL_Delivery_Latency',
                         'MSSQL_Delivered_Commands',
                         'MSSQL_Delivered_Transactions',
                         'MSSQL_Conflicts',
                         'MSSQL_Uploaded_Changes',
                         'MSSQL_Downloaded_Changes',
                         'MSSQL_Active_Transactions',
                         'MSSQL_Transactions_Rate',
                         'MSSQL_Log_File_Size',
                         'MSSQL_Log_Space_Percent_Used_Actual',
                         'MSSQL_Database_Size',
                         'MSSQL_Database_Space_Percent_Used_Actual',
                         'MSSQL_Database_Growth_Percent_Actual',
                         'MSSQL_Filegroup_Space_Percent_Used_Actual',
                         'MSSQL_Filegroup_Size',
                         'MSSQL_Error_Count_Transaction_Log_Full',
                         'MSSQL_Error_Count_Disk_IO_Errors',
                         'MSSQL_Error_Count_Connections_High',
                         'MSSQL_Error_Count_Connections_Failed',
                         'MSSQL_Error_Count_Allocate_Space_Failed',
                         'MSSQL_Error_Count_Transaction_Log_Errors',
                         'MSSQL_Error_Count_Database_Full',
                         'MSSQL_Error_Count_Deadlock_Alert',
                         'MSSQL_Error_Count_Customer_Defined');

insert into session.MGrpMbr
   select 'MIN_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt
    where MsmtTyp_Nm in ('MSSQL_Service_Stopped',
                         'MSSQL_Service_Paused',
                         'MSSQL_Service_Running',
                         'MSSQL_Database_Online',
                         'MSSQL_Database_Suspect',
                         'MSSQL_Logouts',
                         'MSSQL_Logins',
                         'MSSQL_User_Connections',
                         'MSSQL_Percent_User_Connections_Used',
                         'MSSQL_Blocked_Processes',
                         'MSSQL_Buffer_Cache_Hit_Ratio',
                         'MSSQL_Buffer_Extended_Memory_Cache_Hit_Ratio',
                         'MSSQL_Free_Buffers',
                         'MSSQL_Lazy_Writes',
                         'MSSQL_Page_Writes',
                         'MSSQL_Page_Reads',
                         'MSSQL_Read_Ahead_Pages',
                         'MSSQL_Stolen_Page_Count',
                         'MSSQL_Stolen_Page_Count_Growth',
                         'MSSQL_Checkpoint_Writes',
                         'MSSQL_Server_Memory_Used',
                         'MSSQL_CPU_Percent_Busy',
                         'MSSQL_Number_Deadlocks',
                         'MSSQL_Space_Allocation_Failure',
                         'MSSQL_Lock_Waits',
                         'MSSQL_Lock_Requests',
                         'MSSQL_Lock_Timeouts',
                         'MSSQL_Lock_Wait_Time',
                         'MSSQL_Table_Lock_Escalations',
                         'MSSQL_Replication_Pending_Transactions',
                         'MSSQL_Replication_Transaction_Rate',
                         'MSSQL_Delivery_Latency',
                         'MSSQL_Delivered_Commands',
                         'MSSQL_Delivered_Transactions',
                         'MSSQL_Conflicts',
                         'MSSQL_Uploaded_Changes',
                         'MSSQL_Downloaded_Changes',
                         'MSSQL_Active_Transactions',
                         'MSSQL_Transactions_Rate',
                         'MSSQL_Log_File_Size',
                         'MSSQL_Log_Space_Percent_Used_Actual',
                         'MSSQL_Database_Size',
                         'MSSQL_Database_Space_Percent_Used_Actual',
                         'MSSQL_Database_Growth_Percent_Actual',
                         'MSSQL_Filegroup_Space_Percent_Used_Actual',
                         'MSSQL_Filegroup_Size',
                         'MSSQL_Error_Count_Transaction_Log_Full',
                         'MSSQL_Error_Count_Disk_IO_Errors',
                         'MSSQL_Error_Count_Connections_High',
                         'MSSQL_Error_Count_Connections_Failed',
                         'MSSQL_Error_Count_Allocate_Space_Failed',
                         'MSSQL_Error_Count_Transaction_Log_Errors',
                         'MSSQL_Error_Count_Database_Full',
                         'MSSQL_Error_Count_Deadlock_Alert',
                         'MSSQL_Error_Count_Customer_Defined');

insert into session.MGrpMbr
   select 'TOT_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt
    where MsmtTyp_Nm in ('MSSQL_Job_Failed',
                         'MSSQL_Job_Succeeded',
                         'MSSQL_Job_Cancelled',
                         'MSSQL_Job_Retry',
                         'MSSQL_Job_In_Progress',
                         'MSSQL_Job_Not_Run',
                         'MSSQL_Job_Duration',
                         'MSSQL_Replication_Job_Failed',
                         'MSSQL_Replication_Job_Between_Retries',
                         'MSSQL_Replication_Job_Retry',
                         'MSSQL_Replication_Job_Idle',
                         'MSSQL_Replication_Job_In_Progress',
                         'MSSQL_Replication_Job_Cancelled',
                         'MSSQL_Replication_Job_Waiting_For_Thread',
                         'MSSQL_Replication_Job_Succeeded',
                         'MSSQL_Replication_Job_Executing',
                         'MSSQL_Replication_Job_Suspended',
                         'MSSQL_Replication_Job_Performing_Completion_Actions' );

-- insert the measurement group member into the generic schema
-- if not exist already

insert into TWG.MGrpMbr (MGRP_CD, MGRPTYP_CD, MSMTTYP_ID)
   select m.MGrp_Cd,
          m.MGrpTyp_Cd,
          m.MsmtTyp_ID
     from session.MGrpMbr m
    where not exists ( select 1 from TWG.MGrpMbr t
                        where t.MGrpTyp_Cd=m.MGrpTyp_Cd
                          and t.MGrp_Cd=m.MGrp_Cd
                          and t.MsmtTyp_ID=m.MsmtTyp_ID )
;
----------------------------------------------
-- link the ITM Resource to the compTyp_cd (RM's)
----------------------------------------------

declare global temporary table AMX_Resource_Transl (
     resource     varchar(50) not null,
     CompTyp_cd   varchar(17) not null )
 with replace on commit preserve rows not logged
;
insert into session.AMX_Resource_Transl values ('MSSQLService','CTW_SERVICE');
insert into session.AMX_Resource_Transl values ('MSSQLDatabase','CTW_DATABASE');
insert into session.AMX_Resource_Transl values ('MSSQLServer','CTW_INSTANCE');
insert into session.AMX_Resource_Transl values ('MSSQLFilegroup','CTW_FILEGROUP');
insert into session.AMX_Resource_Transl values ('MSSQLServerReplication','CTW_AGENT');
insert into session.AMX_Resource_Transl values ('MSSQLDatabaseReplication','CTW_REPLICATION');
insert into session.AMX_Resource_Transl values ('MSSQLJobCategory','CTW_JOBCATEGORY');

insert into AMX.Resource_Transl (RESOURCE,  COMPTYP_CD)
   SELECT t.resource as resource,
          t.Comptyp_cd as comptyp_cd
     FROM session.AMX_resource_Transl t
    where not EXISTS ( select 1 FROM AMX.Resource_Transl m
                         WHERE t.comptyp_Cd = m.comptyp_Cd )
;
--------------------------------------------------
-- Need to link the ITM Category to the AVA code
----------------------------------------------

declare global temporary table AMX_Category_Transl (
   category varchar(120) not null,
   MSrc_cd  char(3) not null
) with replace on commit preserve rows not logged
;

insert into session.AMX_Category_Transl values ('Microsoft_SQL_Server','CTW');

insert into AMX.Category_Transl
   select t.category as category, t.Msrc_Cd as Msrc_Cd
     from session.AMX_Category_Transl t
    where not exists ( select 1 from AMX.Category_Transl m
                        where t.Msrc_Cd = m.Msrc_Cd )
;

--------------------------------------------------
-- Need a translation table if the property
-- can have more than 17 characters
-- Need to know which properties are key properties
-- Need to know which properties will be used for the Comp_Nm
--------------------------------------------------

declare global temporary table AMX_CompTyp_Transl (
   Msrc_Cd          char(3) not null,
   ITM_key_property varchar(600) not null,
   Comptyp_cd       varchar(17) not null,
   Comp_format_nm   varchar(120) not null
) with replace on commit preserve rows not logged
;

insert into session.AMX_CompTyp_Transl
   values ('CTW', 'MSSQLService.MSSQLServiceName', 'CTW_SERVICE', 'MSSQLService.MSSQLServiceName');

insert into session.AMX_CompTyp_Transl
   values ('CTW', 'MSSQLDatabase.MSSQLDatabaseName', 'CTW_DATABASE', 'MSSQLDatabase.MSSQLDatabaseName');

insert into session.AMX_CompTyp_Transl
   values ('CTW', 'MSSQLFilegroup.MSSQLFilegroupName', 'CTW_FILEGROUP', 'MSSQLFilegroup.MSSQLFilegroupName');

insert into session.AMX_CompTyp_Transl
   values ('CTW', 'MSSQLServer.MSSQLServerName', 'CTW_INSTANCE', 'MSSQLServer.MSSQLServerName');

insert into session.AMX_CompTyp_Transl
   values ('CTW', 'MSSQLServerReplication.MSSQLAgentType', 'CTW_AGENT', 'MSSQLServerReplication.MSSQLAgentType');

insert into session.AMX_CompTyp_Transl
   values ('CTW', 'MSSQLDatabaseReplication.MSSQLDatabaseName', 'CTW_REPLICATION', 'MSSQLDatabaseReplication.MSSQLDatabaseName');

insert into session.AMX_CompTyp_Transl
   values ('CTW', 'MSSQLJobCategory.MSSQLJobCategory', 'CTW_JOBCATEGORY', 'MSSQLJobCategory.MSSQLJobCategory');

insert into AMX.Comptyp_Transl
   SELECT t.Msrc_Cd as Msrc_Cd,
          t.ITM_key_property as ITM_key_property,
          t.Comptyp_cd as Comptyp_cd,
          t.Comp_format_nm as Comp_format_nm
     FROM session.AMX_Comptyp_Transl t
        where not EXISTS ( select 1 FROM AMX.Comptyp_Transl m
                               WHERE t.Msrc_Cd = m.Msrc_Cd
                                 AND t.Comptyp_cd  = m.Comptyp_cd )
;
--------------------------------------------------
-- Need a translation table if the property
-- can have more than 17 characters
----------------------------------------------
declare global temporary table AMX_AttrTyp_Transl (
   Msrc_Cd           char(3) not null,
   ITM_attr_property varchar(120) not null,
   AttrTyp_cd        varchar(17) not null
) with replace on commit preserve rows not logged
;

insert into session.AMX_AttrTyp_Transl
   values ('CTW','MSSQLDatabase.MSSQLLogFileName','CTW_LOG_FILENAME');

insert into session.AMX_AttrTyp_Transl
   values ('CTW','MSSQLDatabase.MSSQLLogMaximumGrowthSize','CTW_LOG_MAXSIZE');

insert into session.AMX_AttrTyp_Transl
   values ('CTW','MSSQLDatabase.MSSQLDatabaseMaximumGrowthSize','CTW_DB_MAXSIZE');

insert into session.AMX_AttrTyp_Transl
   values ('CTW','MSSQLFilegroup.MSSQLFilegroupMaximumGrowthSize','CTW_FILEG_MAXSIZE');

insert into session.AMX_AttrTyp_Transl
   values ('CTW','MSSQLServer.MSSQLVersion','VERSION');

insert into session.AMX_AttrTyp_Transl
   values ('CTW','MSSQLServer.MSSQLMaxConnections','MAX_CONNECTIONS');

insert into AMX.Attrtyp_Transl
   SELECT t.Msrc_Cd as Msrc_Cd,
          t.ITM_attr_property as ITM_attr_property,
          t.AttrTyp_Cd as AttrTyp_Cd
     FROM session.AMX_Attrtyp_Transl t
       where not EXISTS ( select 1 FROM AMX.Attrtyp_Transl m
                             WHERE t.Msrc_Cd = m.Msrc_Cd
                               AND t.AttrTyp_cd  = m.AttrTyp_cd )
;

-- Add pruning control information int TWG.Prune_Msmt_Control
-- A date duration is decimal(8,0) and has the format yyyymmdd.
-- I believe 300 is 3 months and 10000 is a year

declare global temporary table prune_msmt_control(
       MSrc_Cd              CHAR(6) NOT NULL,
       TmSum_Cd             CHAR NOT NULL,
       PMsmtC_Age_In_Days   DECIMAL(8,0) NOT NULL
) with replace on commit preserve rows not logged
;

insert into session.Prune_Msmt_Control values ('CTW', 'H', 00000300);
insert into session.Prune_Msmt_Control values ('CTW', 'D', 00000300);
insert into session.Prune_Msmt_Control values ('CTW', 'W', 00010000);
insert into session.Prune_Msmt_Control values ('CTW', 'M', 00010000);

insert into TWG.Prune_Msmt_Control
   select * from  session.Prune_Msmt_Control s
      where not EXISTS ( select 1 FROM TWG.Prune_Msmt_Control t
                            WHERE t.MSrc_Cd = s.MSrc_Cd
                              AND t.TmSum_Cd = s.TmSum_Cd )
;
-- Create  extract control for MSSQL metrics and fact tables
-- temporary table for Extract Control

declare global temporary table Extract_Control (
   ExtCtl_Source      varchar(120) not null,
   ExtCtl_Target      varchar(120) not null,
   ExtCtl_From_RawSeq char(10) for bit data,
   ExtCtl_To_RawSeq   char(10) for bit data,
   ExtCtl_From_IntSeq bigint,
   ExtCtl_To_IntSeq   bigint,
   ExtCtl_From_DtTm   timestamp not null,
   ExtCtl_To_DtTm     timestamp not null
) with replace on commit preserve rows not logged
;

-----------------------------------------------
-- From TWG.MSMT to the Mart Fact tables
-----------------------------------------------
insert into session.extract_control values (
    'TWG.MSMT' ,
    'CTW.STG_F_FGROUP_HOUR' ,
    'x',
    'x',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.MSMT' ,
    'CTW.STG_F_DBUSED_HOUR' ,
    'x',
    'x',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.MSMT' ,
    'CTW.STG_F_SRVAVAIL_HOUR' ,
    'x',
    'x',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);
insert into session.extract_control values (
    'TWG.MSMT' ,
    'CTW.STG_F_SRVUSAGE_HOUR' ,
    'x',
    'x',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);
insert into session.extract_control values (
    'TWG.MSMT' ,
    'CTW.STG_F_ERROR_HOUR',
    'x',
    'x',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);
insert into session.extract_control values (
    'TWG.MSMT' ,
    'CTW.STG_F_AGENT_HOUR',
    'x',
    'x',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);
insert into session.extract_control values (
    'TWG.MSMT' ,
    'CTW.STG_F_REPL_HOUR',
    'x',
    'x',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);
insert into session.extract_control values (
    'TWG.MSMT' ,
    'CTW.STG_F_JOB_HOUR',
    'x',
    'x',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);
insert into session.extract_control values (
    'TWG.MSMT' ,
    'CTW.STG_F_SRVPERF_HOUR',
    'x',
    'x',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-------------------------------------------------------------------
-- Controls for metrics staging to dimension metric tables
----------------------------------------
insert into session.extract_control values (
    'CTW.STG_FGROUP_METRIC' ,
    'CTW.D_FGROUP_METRIC' ,
    'x',
    'x',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'CTW.STG_DBASE_METRIC' ,
    'CTW.D_DBUSAGE_METRIC' ,
    'x',
    'x',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'CTW.STG_SERVER_METRIC' ,
    'CTW.D_SRVUSAGE_METRIC',
    'x',
    'x',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'CTW.STG_SERVICE_METRIC' ,
    'CTW.D_SRVAVAIL_METRIC' ,
    'x',
    'x',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'CTW.STG_AGENT_METRIC' ,
    'CTW.D_AGENT_METRIC' ,
    'x',
    'x',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'CTW.STG_SERVER_METRIC',
    'CTW.D_ERROR_METRIC',
    'x',
    'x',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'CTW.STG_JOB_METRIC',
    'CTW.D_JOB_METRIC',
    'x',
    'x',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'CTW.STG_REPL_METRIC',
    'CTW.D_REPL_METRIC',
    'x',
    'x',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'CTW.STG_SERVER_METRIC',
    'CTW.D_SRVPERF_METRIC',
    'x',
    'x',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-----------------------------------------------
-- From TWG.COMP to the Mart Dimension tables
-----------------------------------------------
insert into session.extract_control values (
    'TWG.COMP',
    'CTW.D_JOBCATEGORY' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);
insert into session.extract_control values (
    'TWG.COMP',
    'CTW.D_DATAFILE' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);
insert into session.extract_control values (
    'TWG.COMP',
    'CTW.D_INSTANCE' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);
insert into session.extract_control values (
    'TWG.COMP',
    'CTW.D_DATABASE' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);
insert into session.extract_control values (
    'TWG.COMP',
    'CTW.D_SERVICE' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);
insert into session.extract_control values (
    'TWG.COMP',
    'CTW.D_AGENT' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);
insert into session.extract_control values (
    'TWG.COMP',
    'CTW.D_HOST' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);
insert into session.extract_control values (
    'TWG.COMP',
    'CTW.D_MESSAGEID' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.COMP',
    'CTW.D_FILEGROUP' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.COMP',
    'CTW.D_REPLICATION' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-- insert from temporary table to extract control
-- if not exist already
insert into TWG.Extract_control
   select m.ExtCtl_Source      as ExtCtl_Source,
          m.ExtCtl_Target      as ExtCtl_Target,
          m.ExtCtl_From_RawSeq as ExtCtl_From_RawSeq,
          m.ExtCtl_To_RawSeq   as ExtCtl_To_RawSeq,
          m.ExtCtl_From_IntSeq as ExtCtl_From_IntSeq,
          m.ExtCtl_To_IntSeq   as ExtCtl_To_IntSeq,
          m.ExtCtl_From_DtTm   as ExtCtl_From_DtTm,
          m.ExtCtl_To_DtTm     as ExtCtl_To_DtTm
     from session.Extract_Control m
    where not exists ( select 1 FROM TWG.Extract_Control t
                          WHERE t.ExtCtl_Source=m.ExtCtl_Source
                            AND t.ExtCtl_Target=m.ExtCtl_Target )
;

--------------------------------------
-- This starts the actual metrics creation
-- for the datamart.
------------------------------------------
-- first some temp tables with indicators if min, max, etc
-- exists for measurement attributs using CTW pac id

declare global temporary table temp_min_exists (
    msmttyp_id integer,
    min_exists char(1)
) with replace on commit preserve rows not logged
;

insert into session.temp_min_exists
   SELECT mb.msmttyp_id,
          'Y' as min_exists
     FROM TWG.MgrpMbr mb, TWG.MsmtTyp mt
       WHERE mb.msmttyp_id=mb.msmttyp_id
         AND mt.msrc_cd ='CTW'
         AND mb.mgrptyp_cd = 'GROUP'
         AND mb.mgrp_cd ='MIN_E'
       group by mb.msmttyp_id
;

declare global temporary table temp_max_exists (
    msmttyp_id integer,
    max_exists char(1)
) with replace on commit preserve rows not logged
;

insert into session.temp_max_exists
   SELECT mb.msmttyp_id,
          'Y' as min_exists
     FROM TWG.MgrpMbr mb, TWG.MsmtTyp mt
       WHERE mb.msmttyp_id=mb.msmttyp_id
         AND mt.msrc_cd ='CTW'
         AND mb.mgrptyp_cd = 'GROUP'
         AND mb.mgrp_cd ='MAX_E'
       group by mb.msmttyp_id
;

declare global temporary table temp_avg_exists (
    msmttyp_id integer,
    avg_exists char(1)
) with replace on commit preserve rows not logged
;

insert into session.temp_avg_exists
   SELECT mb.msmttyp_id,
          'Y' as min_exists
     FROM TWG.MgrpMbr mb, TWG.MsmtTyp mt
       WHERE mb.msmttyp_id=mb.msmttyp_id
         AND mt.msrc_cd ='CTW'
         AND mb.mgrptyp_cd = 'GROUP'
         AND mb.mgrp_cd ='AVG_E'
       group by mb.msmttyp_id
;

declare global temporary table temp_tot_exists (
    msmttyp_id integer,
    tot_exists char(1)
) with replace on commit preserve rows not logged
;

insert into session.temp_tot_exists
   SELECT mb.msmttyp_id,
          'Y' as min_exists
     FROM TWG.MgrpMbr mb, TWG.MsmtTyp mt
       WHERE mb.msmttyp_id=mb.msmttyp_id
         AND mt.msrc_cd ='CTW'
         AND mb.mgrptyp_cd = 'GROUP'
         AND mb.mgrp_cd ='TOT_E'
       group by mb.msmttyp_id
;
------------------------------------------------
-- create database filegroup metric staging table
------------------------------------------------
DELETE FROM CTW.STG_FGROUP_METRIC;

insert  into CTW.STG_FGROUP_METRIC
   SELECT current timestamp - current timezone as insert_dttm,
          mt1.msmttyp_id as metric_id,
          mt1.msmttyp_nm as met_name,
          mt1.msmttyp_ds as met_desc,
          mt1.munit_cd as met_units ,
          'Not used' as met_category,
          s.msrc_nm as msrc_nm,
          value(min.min_exists,'N') as min_exists,
          value(max.max_exists,'N') as max_exists,
          value(avg.avg_exists,'N') as avg_exists,
          value(tot.tot_exists,'N') as total_exists
     from twg.msmttyp mt1 left outer join session.temp_min_exists min
               on mt1.msmttyp_id = min.msmttyp_id,
          twg.msmttyp mt2 left outer join session.temp_max_exists max
               on mt2.msmttyp_id = max.msmttyp_id,
          twg.msmttyp mt3 left outer join session.temp_avg_exists avg
               on mt3.msmttyp_id = avg.msmttyp_id,
          twg.msmttyp mt4 left outer join session.temp_tot_exists tot
               on mt4.msmttyp_id = tot.msmttyp_id,
          TWG.MsmtRul mr,
          TWG.msrc s
    WHERE mt1.msmttyp_id = mr.msmttyp_id
      and mr.comptyp_cd = 'CTW_FILEGROUP'
      AND mt1.MSrc_Cd = 'CTW'
      AND s.msrc_cd = mt1.Msrc_cd
      AND mt1.msmttyp_id = mt2.msmttyp_id
      AND mt1.msmttyp_id = mt3.msmttyp_id
      AND mt1.msmttyp_id = mt4.msmttyp_id
      AND not exists (select 1 from CTW.STG_FGROUP_METRIC m
                        WHERE m.metric_id = mt1.msmttyp_id
                          AND m.msrc_nm = 'CTW')
    group BY mt1.msmttyp_id, mt1.msmttyp_nm, mt1.msmttyp_ds, mt1.munit_cd,
             min_exists, avg_exists, tot_exists, max_exists, s.msrc_nm
;
--SELECT * FROM CTW.STG_FGROUP_METRIC;
------------------------------------------------
-- create server service availability metric staging table
------------------------------------------------
DELETE FROM CTW.STG_SERVICE_METRIC;

insert  into CTW.STG_SERVICE_METRIC
   SELECT current timestamp - current timezone as insert_dttm,
          mt1.msmttyp_id as metric_id,
          mt1.msmttyp_nm as met_name,
          mt1.msmttyp_ds as met_desc,
          mt1.munit_cd as met_units ,
          'Not used' as met_category,
          s.msrc_nm as msrc_nm,
          value(min.min_exists,'N') as min_exists,
          value(max.max_exists,'N') as max_exists,
          value(avg.avg_exists,'N') as avg_exists,
          value(tot.tot_exists,'N') as total_exists
     from twg.msmttyp mt1 left outer join session.temp_min_exists min
               on mt1.msmttyp_id = min.msmttyp_id,
          twg.msmttyp mt2 left outer join session.temp_max_exists max
               on mt2.msmttyp_id = max.msmttyp_id,
          twg.msmttyp mt3 left outer join session.temp_avg_exists avg
               on mt3.msmttyp_id = avg.msmttyp_id,
          twg.msmttyp mt4 left outer join session.temp_tot_exists tot
               on mt4.msmttyp_id = tot.msmttyp_id,
          TWG.MsmtRul mr,
          TWG.msrc s
    WHERE mt1.msmttyp_id = mr.msmttyp_id
      and mr.comptyp_cd = 'CTW_SERVICE'
      AND mt1.MSrc_Cd='CTW'
      AND s.msrc_cd=mt1.Msrc_cd
      AND mt1.msmttyp_id = mt2.msmttyp_id
      AND mt1.msmttyp_id = mt3.msmttyp_id
      AND mt1.msmttyp_id = mt4.msmttyp_id
      AND not exists (select 1 from CTW.STG_SERVICE_METRIC m
                        WHERE m.metric_id = mt1.msmttyp_id
                          AND m.msrc_nm = 'CTW')
    group BY mt1.msmttyp_id, mt1.msmttyp_nm, mt1.msmttyp_ds, mt1.munit_cd,
             min_exists, avg_exists, tot_exists, max_exists, s.msrc_nm
;
--SELECT * FROM CTW.STG_SERVICE_METRIC;
------------------------------------------------
-- create server metric staging table
------------------------------------------------
DELETE FROM CTW.STG_SERVER_METRIC;

insert  into CTW.STG_SERVER_METRIC
   SELECT current timestamp - current timezone as insert_dttm,
          mt1.msmttyp_id as metric_id,
          mt1.msmttyp_nm as met_name,
          mt1.msmttyp_ds as met_desc,
          mt1.munit_cd as met_units ,
          'Not used' as met_category,
          s.msrc_nm as msrc_nm,
          value(min.min_exists,'N') as min_exists,
          value(max.max_exists,'N') as max_exists,
          value(avg.avg_exists,'N') as avg_exists,
          value(tot.tot_exists,'N') as total_exists
     from twg.msmttyp mt1 left outer join session.temp_min_exists min
               on mt1.msmttyp_id = min.msmttyp_id,
          twg.msmttyp mt2 left outer join session.temp_max_exists max
               on mt2.msmttyp_id = max.msmttyp_id,
          twg.msmttyp mt3 left outer join session.temp_avg_exists avg
               on mt3.msmttyp_id = avg.msmttyp_id,
          twg.msmttyp mt4 left outer join session.temp_tot_exists tot
               on mt4.msmttyp_id = tot.msmttyp_id,
          TWG.MsmtRul mr,
          TWG.msrc s
    WHERE mt1.msmttyp_id = mr.msmttyp_id
      and mr.comptyp_cd = 'CTW_INSTANCE'
      AND mt1.MSrc_Cd='CTW'
      AND s.msrc_cd=mt1.Msrc_cd
      AND mt1.msmttyp_id = mt2.msmttyp_id
      AND mt1.msmttyp_id = mt3.msmttyp_id
      AND mt1.msmttyp_id = mt4.msmttyp_id
      AND not exists (select 1 from CTW.STG_SERVER_METRIC m
                        WHERE m.metric_id = mt1.msmttyp_id
                          AND m.msrc_nm = 'CTW')
    group BY mt1.msmttyp_id, mt1.msmttyp_nm, mt1.msmttyp_ds, mt1.munit_cd,
             min_exists, avg_exists, tot_exists, max_exists, s.msrc_nm
;
--SELECT * FROM CTW.STG_SERVER_METRIC;
------------------------------------------------
-- create database average usage  metric staging table
------------------------------------------------
DELETE FROM CTW.STG_DBASE_METRIC;

insert  into CTW.STG_DBASE_METRIC
   SELECT current timestamp - current timezone as insert_dttm,
          mt1.msmttyp_id as metric_id,
          mt1.msmttyp_nm as met_name,
          mt1.msmttyp_ds as met_desc,
          mt1.munit_cd as met_units ,
          'Not used' as met_category,
          s.msrc_nm as msrc_nm,
          value(min.min_exists,'N') as min_exists,
          value(max.max_exists,'N') as max_exists,
          value(avg.avg_exists,'N') as avg_exists,
          value(tot.tot_exists,'N') as total_exists
     from twg.msmttyp mt1 left outer join session.temp_min_exists min
               on mt1.msmttyp_id = min.msmttyp_id,
          twg.msmttyp mt2 left outer join session.temp_max_exists max
               on mt2.msmttyp_id = max.msmttyp_id,
          twg.msmttyp mt3 left outer join session.temp_avg_exists avg
               on mt3.msmttyp_id = avg.msmttyp_id,
          twg.msmttyp mt4 left outer join session.temp_tot_exists tot
               on mt4.msmttyp_id = tot.msmttyp_id,
          TWG.MsmtRul mr,
          TWG.msrc s
    WHERE mt1.msmttyp_id = mr.msmttyp_id
      and mr.comptyp_cd = 'CTW_DATABASE'
      AND mt1.MSrc_Cd='CTW'
      AND s.msrc_cd=mt1.Msrc_cd
      AND mt1.msmttyp_id = mt2.msmttyp_id
      AND mt1.msmttyp_id = mt3.msmttyp_id
      AND mt1.msmttyp_id = mt4.msmttyp_id
      AND not exists (select 1 from CTW.STG_DBASE_METRIC m
                        WHERE m.metric_id = mt1.msmttyp_id
                          AND m.msrc_nm = 'CTW')
    group BY mt1.msmttyp_id, mt1.msmttyp_nm, mt1.msmttyp_ds, mt1.munit_cd,
             min_exists, avg_exists, tot_exists, max_exists, s.msrc_nm
;
--SELECT * FROM CTW.STG_DBASE_METRIC;
------------------------------------------------
-- create agent latency metric staging table
------------------------------------------------
DELETE FROM CTW.STG_AGENT_METRIC;

insert  into CTW.STG_AGENT_METRIC
   SELECT current timestamp - current timezone as insert_dttm,
          mt1.msmttyp_id as metric_id,
          mt1.msmttyp_nm as met_name,
          mt1.msmttyp_ds as met_desc,
          mt1.munit_cd as met_units ,
          'Not used' as met_category,
          s.msrc_nm as msrc_nm,
          value(min.min_exists,'N') as min_exists,
          value(max.max_exists,'N') as max_exists,
          value(avg.avg_exists,'N') as avg_exists,
          value(tot.tot_exists,'N') as total_exists
     from twg.msmttyp mt1 left outer join session.temp_min_exists min
               on mt1.msmttyp_id = min.msmttyp_id,
          twg.msmttyp mt2 left outer join session.temp_max_exists max
               on mt2.msmttyp_id = max.msmttyp_id,
          twg.msmttyp mt3 left outer join session.temp_avg_exists avg
               on mt3.msmttyp_id = avg.msmttyp_id,
          twg.msmttyp mt4 left outer join session.temp_tot_exists tot
               on mt4.msmttyp_id = tot.msmttyp_id,
          TWG.MsmtRul mr,
          TWG.msrc s
    WHERE mt1.msmttyp_id = mr.msmttyp_id
      and mr.comptyp_cd = 'CTW_AGENT'
      AND mt1.MSrc_Cd='CTW'
      AND s.msrc_cd=mt1.Msrc_cd
      AND mt1.msmttyp_id = mt2.msmttyp_id
      AND mt1.msmttyp_id = mt3.msmttyp_id
      AND mt1.msmttyp_id = mt4.msmttyp_id
      AND not exists (select 1 from CTW.STG_AGENT_METRIC m
                        WHERE m.metric_id = mt1.msmttyp_id
                          AND m.msrc_nm = 'CTW')
    group BY mt1.msmttyp_id, mt1.msmttyp_nm, mt1.msmttyp_ds, mt1.munit_cd,
             min.min_exists, avg.avg_exists, tot.tot_exists, max.max_exists, s.msrc_nm
;
--SELECT * FROM CTW.STG_AGENT_METRIC;
------------------------------------------------
-- create job category metric staging table
------------------------------------------------
DELETE FROM CTW.STG_JOB_METRIC;

insert  into CTW.STG_JOB_METRIC
   SELECT current timestamp - current timezone as insert_dttm,
          mt1.msmttyp_id as metric_id,
          mt1.msmttyp_nm as met_name,
          mt1.msmttyp_ds as met_desc,
          mt1.munit_cd as met_units ,
          'Not used' as met_category,
          s.msrc_nm as msrc_nm,
          value(min.min_exists,'N') as min_exists,
          value(max.max_exists,'N') as max_exists,
          value(avg.avg_exists,'N') as avg_exists,
          value(tot.tot_exists,'N') as total_exists
     from twg.msmttyp mt1 left outer join session.temp_min_exists min
               on mt1.msmttyp_id = min.msmttyp_id,
          twg.msmttyp mt2 left outer join session.temp_max_exists max
               on mt2.msmttyp_id = max.msmttyp_id,
          twg.msmttyp mt3 left outer join session.temp_avg_exists avg
               on mt3.msmttyp_id = avg.msmttyp_id,
          twg.msmttyp mt4 left outer join session.temp_tot_exists tot
               on mt4.msmttyp_id = tot.msmttyp_id,
          TWG.MsmtRul mr,
          TWG.msrc s
    WHERE mt1.msmttyp_id = mr.msmttyp_id
      and mr.comptyp_cd = 'CTW_JOBCATEGORY'
      AND mt1.MSrc_Cd='CTW'
      AND s.msrc_cd=mt1.Msrc_cd
      AND mt1.msmttyp_id = mt2.msmttyp_id
      AND mt1.msmttyp_id = mt3.msmttyp_id
      AND mt1.msmttyp_id = mt4.msmttyp_id
      AND not exists (select 1 from CTW.STG_JOB_METRIC m
                        WHERE m.metric_id = mt1.msmttyp_id
                          AND m.msrc_nm = 'CTW')
    group BY mt1.msmttyp_id, mt1.msmttyp_nm, mt1.msmttyp_ds, mt1.munit_cd,
             min.min_exists, avg.avg_exists, tot.tot_exists, max.max_exists, s.msrc_nm
;
--SELECT * FROM CTW.STG_JOB_METRIC;
------------------------------------------------
-- create sql server replication metric staging table
------------------------------------------------
DELETE FROM CTW.STG_REPL_METRIC;

insert  into CTW.STG_REPL_METRIC
   SELECT current timestamp - current timezone as insert_dttm,
          mt1.msmttyp_id as metric_id,
          mt1.msmttyp_nm as met_name,
          mt1.msmttyp_ds as met_desc,
          mt1.munit_cd as met_units ,
          'Not used' as met_category,
          s.msrc_nm as msrc_nm,
          value(min.min_exists,'N') as min_exists,
          value(max.max_exists,'N') as max_exists,
          value(avg.avg_exists,'N') as avg_exists,
          value(tot.tot_exists,'N') as total_exists
     from twg.msmttyp mt1 left outer join session.temp_min_exists min
               on mt1.msmttyp_id = min.msmttyp_id,
          twg.msmttyp mt2 left outer join session.temp_max_exists max
               on mt2.msmttyp_id = max.msmttyp_id,
          twg.msmttyp mt3 left outer join session.temp_avg_exists avg
               on mt3.msmttyp_id = avg.msmttyp_id,
          twg.msmttyp mt4 left outer join session.temp_tot_exists tot
               on mt4.msmttyp_id = tot.msmttyp_id,
          TWG.MsmtRul mr,
          TWG.msrc s
    WHERE mt1.msmttyp_id = mr.msmttyp_id
      and mr.comptyp_cd = 'CTW_REPLICATION'
      AND mt1.MSrc_Cd='CTW'
      AND s.msrc_cd=mt1.Msrc_cd
      AND mt1.msmttyp_id = mt2.msmttyp_id
      AND mt1.msmttyp_id = mt3.msmttyp_id
      AND mt1.msmttyp_id = mt4.msmttyp_id
      AND not exists (select 1 from CTW.STG_REPL_METRIC m
                        WHERE m.metric_id = mt1.msmttyp_id
                          AND m.msrc_nm = 'CTW')
    group BY mt1.msmttyp_id, mt1.msmttyp_nm, mt1.msmttyp_ds, mt1.munit_cd,
             min.min_exists, avg.avg_exists, tot.tot_exists, max.max_exists, s.msrc_nm
;
--SELECT * FROM CTW.STG_REPL_METRIC;
-- end --
