-- ##########################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  5724-B96
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #   File Information: src/tedw_apps_etl/ctw/pkg/v110/etl/sql/ctw_m05_s020_Fact.db2
-- #   Revision: 1.4
-- #   Date: 1/02/03 17:56:27
-- ############################################################################
--------------------------------------------------------------------------------
-- insert the facts for MSSQL
----------------------------------------------
-- Insert into the Server Availability Fact Table
----------------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table CTW.STG_F_SRVAVAIL_HOUR;

--#EXECUTE_AT_TARGET
create table CTW.STG_F_SRVAVAIL_HOUR like CTW.F_SRVAVAIL_HOUR;

update TWG.Extract_Control
   set extctl_to_intseq = ( select max(m1.msmt_id) from twg.comp c1,
                                                        twg.msmt m1
                             where c1.comptyp_cd = 'CTW_SERVICE'
                               and c1.comp_id    = m1.comp_id )
 where extctl_source = 'TWG.MSMT'
   and extctl_target = 'CTW.STG_F_SRVAVAIL_HOUR'
   and exists ( select m2.msmt_id from twg.comp c2, twg.msmt m2
                 where c2.comptyp_cd = 'CTW_SERVICE'
                   and c2.comp_id    = m2.comp_id)
;
--#INSERT_INTO_TARGET
insert into CTW.STG_F_SRVAVAIL_HOUR
   select m.msmttyp_id as metric_id,
          c1.comp_id as service_id,
          timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
          avg(m.msmt_min_val) as min_value,
          avg(m.msmt_max_val) as max_value,
          avg(m.msmt_avg_val) as avg_value,
          avg(m.msmt_tot_val) as total_value,
          avg(m.msmt_smpl_cnt) as sample_count,
          c2.comp_id as host_id
     from TWG.Msmt m,
          TWG.Comp c1,
          TWG.Comp c2,
          TWG.Extract_control ec
    where ec.extctl_source = 'TWG.MSMT'
      and ec.extctl_target = 'CTW.STG_F_SRVAVAIL_HOUR'
      and m.msmt_id > ec.extctl_from_intseq
      and m.msmt_id <= ec.extctl_to_intseq
      and m.tmsum_cd = 'H'
      and c1.comp_id = m.comp_id
      and c1.comptyp_cd = 'CTW_SERVICE'
      and c2.comp_id = c1.comp_corr_id
      and c2.comptyp_cd in ( 'CTW_HOST', 'IP_HOST' )
    GROUP BY m.msmttyp_id, c1.comp_id, c2.comp_id, m.comp_id,
             timestamp (m.msmt_strt_dt,m.msmt_strt_tm)
;
-- confirm that the insertion of the facts has succeeded
-- insert a row in the TWG.EXTRACT_LOG
insert into twg.extract_log
   select ec.extctl_source as extlog_source,
          ec.extctl_target as extlog_target,
          current timestamp as extlog_done_dttm,
          ec.extctl_from_rawseq as extlog_from_rawseq,
          ec.extctl_to_rawseq as extlog_to_rawseq,
          ec.extctl_from_intseq as extlog_from_intseq,
          ec.extctl_to_intseq as extlog_to_intseq,
          ec.extctl_from_dttm as extlog_from_dttm,
          ec.extctl_to_dttm as extlog_to_dttm
     from TWG.Extract_control ec
    where ec.extctl_source = 'TWG.MSMT'
      and ec.extctl_target = 'CTW.STG_F_SRVAVAIL_HOUR'
;
--#EXECUTE_AT_TARGET
insert into CTW.F_SRVAVAIL_HOUR
   select * from CTW.STG_F_SRVAVAIL_HOUR;

----------------------------------------------
-- Insert into the Filegroup file space Fact Table
----------------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table CTW.STG_F_FGROUP_HOUR;

--#EXECUTE_AT_TARGET
create table CTW.STG_F_FGROUP_HOUR like CTW.F_FGROUP_HOUR;

update TWG.Extract_Control
   set extctl_to_intseq = ( select max(m1.msmt_id) from twg.comp c1,
                                                        twg.msmt m1
                             where c1.comptyp_cd = 'CTW_FILEGROUP'
                               and c1.comp_id    = m1.comp_id )
 where extctl_source = 'TWG.MSMT'
   and extctl_target = 'CTW.STG_F_FGROUP_HOUR'
   and exists ( select m2.msmt_id from twg.comp c2, twg.msmt m2
                 where c2.comptyp_cd = 'CTW_FILEGROUP'
                   and c2.comp_id    = m2.comp_id)
;
--#INSERT_INTO_TARGET
insert into CTW.STG_F_FGROUP_HOUR
   select m.msmttyp_id as metric_id,
          c1.comp_id   as filegroup_id,
          c2.comp_id   as database_id,
          c3.comp_id   as instance_id,
          timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
          avg(m.msmt_min_val) as min_value,
          avg(m.msmt_max_val) as max_value,
          avg(m.msmt_avg_val) as avg_value,
          avg(m.msmt_tot_val) as total_value,
          avg(m.msmt_smpl_cnt) as sample_count,
          c4.comp_id   as host_id
     from TWG.Msmt m,
          TWG.Comp c1,
          TWG.Comp c2,
          TWG.Comp c3,
          TWG.Comp c4,
          TWG.Extract_control ec
    where ec.extctl_source = 'TWG.MSMT'
      and ec.extctl_target = 'CTW.STG_F_FGROUP_HOUR'
      and m.msmt_id  > ec.extctl_from_intseq
      and m.msmt_id <= ec.extctl_to_intseq
      and m.tmsum_cd = 'H'
      and c1.comp_id    = m.comp_id
      and c1.comptyp_cd = 'CTW_FILEGROUP'
      and c2.comp_id    =  c1.comp_corr_id
      and c2.comptyp_cd = 'CTW_DATABASE'
      and c3.comp_id    =  c2.comp_corr_id
      and c3.comptyp_cd = 'CTW_INSTANCE'
      and c4.comp_id    =  c3.comp_corr_id
      and c4.comptyp_cd in ( 'CTW_HOST', 'IP_HOST' )
    GROUP BY m.msmttyp_id, c1.comp_id, c2.comp_id, c3.comp_id, c4.comp_id,
             m.comp_id, timestamp (m.msmt_strt_dt,m.msmt_strt_tm)
;
-- confirm that the insertion of the facts has succeeded
-- insert a row in the TWG.EXTRACT_LOG
insert into twg.extract_log
   select ec.extctl_source as extlog_source,
          ec.extctl_target as extlog_target,
          current timestamp as extlog_done_dttm,
          ec.extctl_from_rawseq as extlog_from_rawseq,
          ec.extctl_to_rawseq as extlog_to_rawseq,
          ec.extctl_from_intseq as extlog_from_intseq,
          ec.extctl_to_intseq as extlog_to_intseq,
          ec.extctl_from_dttm as extlog_from_dttm,
          ec.extctl_to_dttm as extlog_to_dttm
     from TWG.Extract_control ec
    where ec.extctl_source = 'TWG.MSMT'
      and ec.extctl_target = 'CTW.STG_F_FGROUP_HOUR'
;
--#EXECUTE_AT_TARGET
insert into CTW.F_FGROUP_HOUR
   select * from CTW.STG_F_FGROUP_HOUR;
----------------------------------------------
-- Insert into the Database average cpu usage Fact Table
----------------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table CTW.STG_F_DBUSED_HOUR;

--#EXECUTE_AT_TARGET
create table CTW.STG_F_DBUSED_HOUR like CTW.F_DBUSED_HOUR;

update TWG.Extract_Control
   set extctl_to_intseq = ( select max(m1.msmt_id) from twg.comp c1,
                                                       twg.msmt m1
                             where c1.comptyp_cd = 'CTW_DATABASE'
                               and c1.comp_id    = m1.comp_id )
 where extctl_source = 'TWG.MSMT'
   and extctl_target = 'CTW.STG_F_DBUSED_HOUR'
   and exists ( select m2.msmt_id from twg.comp c2, twg.msmt m2
                 where c2.comptyp_cd = 'CTW_DATABASE'
                   and c2.comp_id    = m2.comp_id);

--#INSERT_INTO_TARGET
insert into CTW.STG_F_DBUSED_HOUR
   select m.msmttyp_id as metric_id,
          c1.comp_id   as database_id,
          c2.comp_id   as instance_id,
          timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
          avg(m.msmt_min_val) as min_value,
          avg(m.msmt_max_val) as max_value,
          avg(m.msmt_avg_val) as avg_value,
          avg(m.msmt_tot_val) as total_value,
          avg(m.msmt_smpl_cnt) as sample_count,
          c3.comp_id   as host_id
     from TWG.Msmt m,
          TWG.Msmttyp mt,
          TWG.Comp c1,
          TWG.Comp c2,
          TWG.Comp c3,
          TWG.Extract_control ec
    where ec.extctl_source = 'TWG.MSMT'
      and ec.extctl_target = 'CTW.STG_F_DBUSED_HOUR'
      and m.msmt_id  > ec.extctl_from_intseq
      and m.msmt_id <= ec.extctl_to_intseq
      and m.tmsum_cd = 'H'
      and m.msmttyp_id = mt.msmttyp_id
      and mt.msmttyp_nm in ('MSSQL_Active_Transactions',
                            'MSSQL_Transactions_Rate',
                            'MSSQL_Database_Online',
                            'MSSQL_Database_Suspect',
                            'MSSQL_Log_File_Size',
                            'MSSQL_Log_Space_Percent_Used_Actual',
                            'MSSQL_Database_Size',
                            'MSSQL_Database_Space_Percent_Used_Actual',
                            'MSSQL_Database_Growth_Percent_Actual')
      and c1.comp_id = m.comp_id
      and c1.comptyp_cd = 'CTW_DATABASE'
      and c2.comp_id = c1.comp_corr_id
      and c2.comptyp_cd = 'CTW_INSTANCE'
      and c3.comp_id    =  c2.comp_corr_id
      and c3.comptyp_cd in ( 'CTW_HOST', 'IP_HOST' )
    GROUP BY m.msmttyp_id, c1.comp_id, c2.comp_id, c3.comp_id,
             m.comp_id, timestamp (m.msmt_strt_dt,m.msmt_strt_tm)
;
-- confirm that the insertion of the facts has succeeded
-- insert a row in the TWG.EXTRACT_LOG
insert into twg.extract_log
   select ec.extctl_source as extlog_source,
          ec.extctl_target as extlog_target,
          current timestamp as extlog_done_dttm,
          ec.extctl_from_rawseq as extlog_from_rawseq,
          ec.extctl_to_rawseq as extlog_to_rawseq,
          ec.extctl_from_intseq as extlog_from_intseq,
          ec.extctl_to_intseq as extlog_to_intseq,
          ec.extctl_from_dttm as extlog_from_dttm,
          ec.extctl_to_dttm as extlog_to_dttm
     from TWG.Extract_control ec
    where ec.extctl_source = 'TWG.MSMT'
      and ec.extctl_target = 'CTW.STG_F_DBUSED_HOUR'
;
--#EXECUTE_AT_TARGET
insert into CTW.F_DBUSED_HOUR
   select * from CTW.STG_F_DBUSED_HOUR;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table CTW.STG_F_SRVUSAGE_HOUR;

--#EXECUTE_AT_TARGET
create table CTW.STG_F_SRVUSAGE_HOUR like CTW.F_SRVUSAGE_HOUR;

update TWG.Extract_Control
   set extctl_to_intseq = ( select max(m1.msmt_id) from twg.comp c1,
                                                       twg.msmt m1
                             where c1.comptyp_cd = 'CTW_INSTANCE'
                               and c1.comp_id    = m1.comp_id )
 where extctl_source = 'TWG.MSMT'
   and extctl_target = 'CTW.STG_F_SRVUSAGE_HOUR'
   and exists ( select m2.msmt_id from twg.comp c2, twg.msmt m2
                 where c2.comptyp_cd = 'CTW_INSTANCE'
                   and c2.comp_id    = m2.comp_id);

--#INSERT_INTO_TARGET
insert into CTW.STG_F_SRVUSAGE_HOUR
   select m.msmttyp_id as metric_id,
          c1.comp_id      as instance_id,
          timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
          avg(m.msmt_min_val) as min_value,
          avg(m.msmt_max_val) as max_value,
          avg(m.msmt_avg_val) as avg_value,
          avg(m.msmt_tot_val) as total_value,
          avg(m.msmt_smpl_cnt) as sample_count,
          c2.comp_id      as host_id
     from TWG.Msmt m,
          TWG.Msmttyp mt,
          TWG.Comp c1,
          TWG.Comp c2,
          TWG.Extract_control ec
    where ec.extctl_source = 'TWG.MSMT'
      and ec.extctl_target = 'CTW.STG_F_SRVUSAGE_HOUR'
      and m.msmt_id  > ec.extctl_from_intseq
      and m.msmt_id <= ec.extctl_to_intseq
      and m.tmsum_cd = 'H'
      and m.msmttyp_id = mt.msmttyp_id
      and mt.msmttyp_nm in ('MSSQL_Server_Memory_Used',
                            'MSSQL_CPU_Percent_Busy' )
      and c1.comp_id = m.comp_id
      and c1.comptyp_cd = 'CTW_INSTANCE'
      and c2.comp_id    =  c1.comp_corr_id
      and c2.comptyp_cd in ( 'CTW_HOST', 'IP_HOST' )
    GROUP BY m.msmttyp_id, c1.comp_id, c2.comp_id,
             m.comp_id, timestamp (m.msmt_strt_dt,m.msmt_strt_tm)
;
-- confirm that the insertion of the facts has succeeded
-- insert a row in the TWG.EXTRACT_LOG
insert into twg.extract_log
   select ec.extctl_source as extlog_source,
          ec.extctl_target as extlog_target,
          current timestamp as extlog_done_dttm,
          ec.extctl_from_rawseq as extlog_from_rawseq,
          ec.extctl_to_rawseq as extlog_to_rawseq,
          ec.extctl_from_intseq as extlog_from_intseq,
          ec.extctl_to_intseq as extlog_to_intseq,
          ec.extctl_from_dttm as extlog_from_dttm,
          ec.extctl_to_dttm as extlog_to_dttm
     from TWG.Extract_control ec
    where ec.extctl_source = 'TWG.MSMT'
      and ec.extctl_target = 'CTW.STG_F_SRVUSAGE_HOUR'
;
--#EXECUTE_AT_TARGET
insert into CTW.F_SRVUSAGE_HOUR
   select * from CTW.STG_F_SRVUSAGE_HOUR;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table CTW.STG_F_ERROR_HOUR;

--#EXECUTE_AT_TARGET
create table CTW.STG_F_ERROR_HOUR like CTW.F_ERROR_HOUR;

update TWG.Extract_Control
   set extctl_to_intseq = ( select max(m1.msmt_id) from twg.comp c1,
                                                       twg.msmt m1
                             where c1.comptyp_cd = 'CTW_INSTANCE'
                               and c1.comp_id    = m1.comp_id )
 where extctl_source = 'TWG.MSMT'
   and extctl_target = 'CTW.STG_F_ERROR_HOUR'
   and exists ( select m2.msmt_id from twg.comp c2, twg.msmt m2
                 where c2.comptyp_cd = 'CTW_INSTANCE'
                   and c2.comp_id    = m2.comp_id);

--#INSERT_INTO_TARGET
insert into CTW.STG_F_ERROR_HOUR
   select m.msmttyp_id    as metric_id,
          c1.comp_id      as instance_id,
          timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
          avg(m.msmt_min_val) as min_value,
          avg(m.msmt_max_val) as max_value,
          avg(m.msmt_avg_val) as avg_value,
          avg(m.msmt_tot_val) as total_value,
          avg(m.msmt_smpl_cnt) as sample_count,
          c2.comp_id      as host_id
     from TWG.Msmt m,
          TWG.Msmttyp mt,
          TWG.Comp c1,
          TWG.Comp c2,
          TWG.Extract_control ec
    where ec.extctl_source = 'TWG.MSMT'
      and ec.extctl_target = 'CTW.STG_F_ERROR_HOUR'
      and m.msmt_id  > ec.extctl_from_intseq
      and m.msmt_id <= ec.extctl_to_intseq
      and m.tmsum_cd = 'H'
      and m.msmttyp_id = mt.msmttyp_id
      and mt.msmttyp_nm in ('MSSQL_Error_Count_Transaction_Log_Full',
                            'MSSQL_Error_Count_Disk_IO_Errors',
                            'MSSQL_Error_Count_Connections_High',
                            'MSSQL_Error_Count_Connections_Failed',
                            'MSSQL_Error_Count_Allocate_Space_Failed',
                            'MSSQL_Error_Count_Transaction_Log_Errors',
                            'MSSQL_Error_Count_Database_Full',
                            'MSSQL_Error_Count_Deadlock_Alert',
                            'MSSQL_Error_Count_Customer_Defined')
      and c1.comp_id = m.comp_id
      and c1.comptyp_cd = 'CTW_INSTANCE'
      and c2.comp_id    =  c1.comp_corr_id
      and c2.comptyp_cd in ( 'CTW_HOST', 'IP_HOST' )
    GROUP BY m.msmttyp_id, c1.comp_id, c2.comp_id,
             m.comp_id, timestamp (m.msmt_strt_dt,m.msmt_strt_tm)
;
-- confirm that the insertion of the facts has succeeded
-- insert a row in the TWG.EXTRACT_LOG
insert into twg.extract_log
   select ec.extctl_source as extlog_source,
          ec.extctl_target as extlog_target,
          current timestamp as extlog_done_dttm,
          ec.extctl_from_rawseq as extlog_from_rawseq,
          ec.extctl_to_rawseq as extlog_to_rawseq,
          ec.extctl_from_intseq as extlog_from_intseq,
          ec.extctl_to_intseq as extlog_to_intseq,
          ec.extctl_from_dttm as extlog_from_dttm,
          ec.extctl_to_dttm as extlog_to_dttm
     from TWG.Extract_control ec
    where ec.extctl_source = 'TWG.MSMT'
      and ec.extctl_target = 'CTW.STG_F_ERROR_HOUR'
;
--#EXECUTE_AT_TARGET
insert into CTW.F_ERROR_HOUR
   select * from CTW.STG_F_ERROR_HOUR;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table CTW.STG_F_AGENT_HOUR;

--#EXECUTE_AT_TARGET
create table CTW.STG_F_AGENT_HOUR like CTW.F_AGENT_HOUR;

update TWG.Extract_Control
   set extctl_to_intseq = ( select max(m1.msmt_id) from twg.comp c1,
                                                       twg.msmt m1
                             where c1.comptyp_cd = 'CTW_AGENT'
                               and c1.comp_id    = m1.comp_id )
 where extctl_source = 'TWG.MSMT'
   and extctl_target = 'CTW.STG_F_AGENT_HOUR'
   and exists ( select m2.msmt_id from twg.comp c2, twg.msmt m2
                 where c2.comptyp_cd = 'CTW_AGENT'
                   and c2.comp_id    = m2.comp_id);

--#INSERT_INTO_TARGET
insert into CTW.STG_F_AGENT_HOUR
   select m.msmttyp_id as metric_id,
          c1.comp_id   as agent_id,
          c2.comp_id   as instance_id,
          timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
          avg(m.msmt_min_val) as min_value,
          avg(m.msmt_max_val) as max_value,
          avg(m.msmt_avg_val) as avg_value,
          avg(m.msmt_tot_val) as total_value,
          avg(m.msmt_smpl_cnt) as sample_count,
          c3.comp_id   as host_id
     from TWG.Msmt m,
          TWG.Msmttyp mt,
          TWG.Comp c1,
          TWG.Comp c2,
          TWG.Comp c3,
          TWG.Extract_control ec
    where ec.extctl_source = 'TWG.MSMT'
      and ec.extctl_target = 'CTW.STG_F_AGENT_HOUR'
      and m.msmt_id  > ec.extctl_from_intseq
      and m.msmt_id <= ec.extctl_to_intseq
      and m.tmsum_cd = 'H'
      and m.msmttyp_id = mt.msmttyp_id
      and mt.msmttyp_nm in ( 'MSSQL_Delivery_Latency',
                             'MSSQL_Delivered_Commands',
                             'MSSQL_Delivered_Transactions',
                             'MSSQL_Conflicts',
                             'MSSQL_Uploaded_Changes',
                             'MSSQL_Downloaded_Changes' )
      and c1.comp_id = m.comp_id
      and c1.comptyp_cd = 'CTW_AGENT'
      and c2.comp_id = c1.comp_corr_id
      and c2.comptyp_cd = 'CTW_INSTANCE'
      and c3.comp_id    =  c2.comp_corr_id
      and c3.comptyp_cd in ( 'CTW_HOST', 'IP_HOST' )
    GROUP BY m.msmttyp_id, c1.comp_id, c2.comp_id, c3.comp_id,
             m.comp_id, timestamp (m.msmt_strt_dt,m.msmt_strt_tm)
;
-- confirm that the insertion of the facts has succeeded
-- insert a row in the TWG.EXTRACT_LOG
insert into twg.extract_log
   select ec.extctl_source as extlog_source,
          ec.extctl_target as extlog_target,
          current timestamp as extlog_done_dttm,
          ec.extctl_from_rawseq as extlog_from_rawseq,
          ec.extctl_to_rawseq as extlog_to_rawseq,
          ec.extctl_from_intseq as extlog_from_intseq,
          ec.extctl_to_intseq as extlog_to_intseq,
          ec.extctl_from_dttm as extlog_from_dttm,
          ec.extctl_to_dttm as extlog_to_dttm
     from TWG.Extract_control ec
    where ec.extctl_source = 'TWG.MSMT'
      and ec.extctl_target = 'CTW.STG_F_AGENT_HOUR'
;
--#EXECUTE_AT_TARGET
insert into CTW.F_AGENT_HOUR
   select * from CTW.STG_F_AGENT_HOUR;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table CTW.STG_F_JOB_HOUR;

--#EXECUTE_AT_TARGET
create table CTW.STG_F_JOB_HOUR like CTW.F_JOB_HOUR;

update TWG.Extract_Control
   set extctl_to_intseq = ( select max(m1.msmt_id) from twg.comp c1,
                                                       twg.msmt m1
                             where c1.comptyp_cd = 'CTW_JOBCATEGORY'
                               and c1.comp_id    = m1.comp_id )
 where extctl_source = 'TWG.MSMT'
   and extctl_target = 'CTW.STG_F_JOB_HOUR'
   and exists ( select m2.msmt_id from twg.comp c2, twg.msmt m2
                 where c2.comptyp_cd = 'CTW_JOBCATEGORY'
                   and c2.comp_id    = m2.comp_id);

--#INSERT_INTO_TARGET
insert into CTW.STG_F_JOB_HOUR
   select m.msmttyp_id as metric_id,
          c1.comp_id   as replication_id,
          c2.comp_id   as instance_id,
          timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
          avg(m.msmt_min_val) as min_value,
          avg(m.msmt_max_val) as max_value,
          avg(m.msmt_avg_val) as avg_value,
          avg(m.msmt_tot_val) as total_value,
          avg(m.msmt_smpl_cnt) as sample_count,
          c3.comp_id   as host_id
     from TWG.Msmt m,
          TWG.Msmttyp mt,
          TWG.Comp c1,
          TWG.Comp c2,
          TWG.Comp c3,
          TWG.Extract_control ec
    where ec.extctl_source = 'TWG.MSMT'
      and ec.extctl_target = 'CTW.STG_F_JOB_HOUR'
      and m.msmt_id  > ec.extctl_from_intseq
      and m.msmt_id <= ec.extctl_to_intseq
      and m.tmsum_cd = 'H'
      and m.msmttyp_id = mt.msmttyp_id
      and mt.msmttyp_nm in ('MSSQL_Job_Failed',
                            'MSSQL_Job_Succeeded',
                            'MSSQL_Job_Cancelled',
                            'MSSQL_Job_Retry',
                            'MSSQL_Job_In_Progress',
                            'MSSQL_Job_Not_Run',
                            'MSSQL_Job_Duration',
                            'MSSQL_Replication_Job_Failed',
                            'MSSQL_Replication_Job_Between_Retries',
                            'MSSQL_Replication_Job_Retry',
                            'MSSQL_Replication_Job_Idle',
                            'MSSQL_Replication_Job_In_Progress',
                            'MSSQL_Replication_Job_Cancelled',
                            'MSSQL_Replication_Job_Waiting_For_Thread',
                            'MSSQL_Replication_Job_Succeeded',
                            'MSSQL_Replication_Job_Executing',
                            'MSSQL_Replication_Job_Suspended',
                            'MSSQL_Replication_Job_Performing_Completion_Actions')
      and c1.comp_id = m.comp_id
      and c1.comptyp_cd = 'CTW_JOBCATEGORY'
      and c2.comp_id = c1.comp_corr_id
      and c2.comptyp_cd = 'CTW_INSTANCE'
      and c3.comp_id    =  c2.comp_corr_id
      and c3.comptyp_cd in ( 'CTW_HOST', 'IP_HOST' )
    GROUP BY m.msmttyp_id, c1.comp_id, c2.comp_id, c3.comp_id,
             m.comp_id, timestamp (m.msmt_strt_dt,m.msmt_strt_tm)
;
-- confirm that the insertion of the facts has succeeded
-- insert a row in the TWG.EXTRACT_LOG
insert into twg.extract_log
   select ec.extctl_source as extlog_source,
          ec.extctl_target as extlog_target,
          current timestamp as extlog_done_dttm,
          ec.extctl_from_rawseq as extlog_from_rawseq,
          ec.extctl_to_rawseq as extlog_to_rawseq,
          ec.extctl_from_intseq as extlog_from_intseq,
          ec.extctl_to_intseq as extlog_to_intseq,
          ec.extctl_from_dttm as extlog_from_dttm,
          ec.extctl_to_dttm as extlog_to_dttm
     from TWG.Extract_control ec
    where ec.extctl_source = 'TWG.MSMT'
      and ec.extctl_target = 'CTW.STG_F_JOB_HOUR'
;
--#EXECUTE_AT_TARGET
insert into CTW.F_JOB_HOUR
   select * from CTW.STG_F_JOB_HOUR;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table CTW.STG_F_REPL_HOUR;

--#EXECUTE_AT_TARGET
create table CTW.STG_F_REPL_HOUR like CTW.F_REPL_HOUR;

update TWG.Extract_Control
   set extctl_to_intseq = ( select max(m1.msmt_id) from twg.comp c1,
                                                       twg.msmt m1
                             where c1.comptyp_cd = 'CTW_REPLICATION'
                               and c1.comp_id    = m1.comp_id )
 where extctl_source = 'TWG.MSMT'
   and extctl_target = 'CTW.STG_F_REPL_HOUR'
   and exists ( select m2.msmt_id from twg.comp c2, twg.msmt m2
                 where c2.comptyp_cd = 'CTW_REPLICATION'
                   and c2.comp_id    = m2.comp_id);

--#INSERT_INTO_TARGET
insert into CTW.STG_F_REPL_HOUR
   select m.msmttyp_id as metric_id,
          c1.comp_id   as replication_id,
          c2.comp_id   as instance_id,
          timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
          avg(m.msmt_min_val) as min_value,
          avg(m.msmt_max_val) as max_value,
          avg(m.msmt_avg_val) as avg_value,
          avg(m.msmt_tot_val) as total_value,
          avg(m.msmt_smpl_cnt) as sample_count,
          c3.comp_id   as host_id
     from TWG.Msmt m,
          TWG.Msmttyp mt,
          TWG.Comp c1,
          TWG.Comp c2,
          TWG.Comp c3,
          TWG.Extract_control ec
    where ec.extctl_source = 'TWG.MSMT'
      and ec.extctl_target = 'CTW.STG_F_REPL_HOUR'
      and m.msmt_id  > ec.extctl_from_intseq
      and m.msmt_id <= ec.extctl_to_intseq
      and m.tmsum_cd = 'H'
      and m.msmttyp_id = mt.msmttyp_id
      and mt.msmttyp_nm in ('MSSQL_Replication_Pending_Transactions',
                            'MSSQL_Replication_Transaction_Rate')
      and c1.comp_id = m.comp_id
      and c1.comptyp_cd = 'CTW_REPLICATION'
      and c2.comp_id = c1.comp_corr_id
      and c2.comptyp_cd = 'CTW_INSTANCE'
      and c3.comp_id    =  c2.comp_corr_id
      and c3.comptyp_cd in ( 'CTW_HOST', 'IP_HOST' )
    GROUP BY m.msmttyp_id, c1.comp_id, c2.comp_id, c3.comp_id,
             m.comp_id, timestamp (m.msmt_strt_dt,m.msmt_strt_tm)
;
-- confirm that the insertion of the facts has succeeded
-- insert a row in the TWG.EXTRACT_LOG
insert into twg.extract_log
   select ec.extctl_source as extlog_source,
          ec.extctl_target as extlog_target,
          current timestamp as extlog_done_dttm,
          ec.extctl_from_rawseq as extlog_from_rawseq,
          ec.extctl_to_rawseq as extlog_to_rawseq,
          ec.extctl_from_intseq as extlog_from_intseq,
          ec.extctl_to_intseq as extlog_to_intseq,
          ec.extctl_from_dttm as extlog_from_dttm,
          ec.extctl_to_dttm as extlog_to_dttm
     from TWG.Extract_control ec
    where ec.extctl_source = 'TWG.MSMT'
      and ec.extctl_target = 'CTW.STG_F_REPL_HOUR'
;
--#EXECUTE_AT_TARGET
insert into CTW.F_REPL_HOUR
   select * from CTW.STG_F_REPL_HOUR;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table CTW.STG_F_SRVPERF_HOUR;

--#EXECUTE_AT_TARGET
create table CTW.STG_F_SRVPERF_HOUR like CTW.F_SRVPERF_HOUR;

update TWG.Extract_Control
   set extctl_to_intseq = ( select max(m1.msmt_id) from twg.comp c1,
                                                       twg.msmt m1
                             where c1.comptyp_cd = 'CTW_INSTANCE'
                               and c1.comp_id    = m1.comp_id )
 where extctl_source = 'TWG.MSMT'
   and extctl_target = 'CTW.STG_F_SRVPERF_HOUR'
   and exists ( select m2.msmt_id from twg.comp c2, twg.msmt m2
                 where c2.comptyp_cd = 'CTW_INSTANCE'
                   and c2.comp_id    = m2.comp_id);

--#INSERT_INTO_TARGET
insert into CTW.STG_F_SRVPERF_HOUR
   select m.msmttyp_id as metric_id,
          c1.comp_id   as instance_id,
          timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
          avg(m.msmt_min_val) as min_value,
          avg(m.msmt_max_val) as max_value,
          avg(m.msmt_avg_val) as avg_value,
          avg(m.msmt_tot_val) as total_value,
          avg(m.msmt_smpl_cnt) as sample_count,
          c2.comp_id   as host_id
     from TWG.Msmt m,
          TWG.Msmttyp mt,
          TWG.Comp c1,
          TWG.Comp c2,
          TWG.Extract_control ec
    where ec.extctl_source = 'TWG.MSMT'
      and ec.extctl_target = 'CTW.STG_F_SRVPERF_HOUR'
      and m.msmt_id  > ec.extctl_from_intseq
      and m.msmt_id <= ec.extctl_to_intseq
      and m.tmsum_cd = 'H'
      and m.msmttyp_id = mt.msmttyp_id
      and mt.msmttyp_nm not in ('MSSQL_Error_Count_Transaction_Log_Full',
                                'MSSQL_Error_Count_Disk_IO_Errors',
                                'MSSQL_Error_Count_Connections_High',
                                'MSSQL_Error_Count_Connections_Failed',
                                'MSSQL_Error_Count_Allocate_Space_Failed',
                                'MSSQL_Error_Count_Transaction_Log_Errors',
                                'MSSQL_Error_Count_Database_Full',
                                'MSSQL_Error_Count_Deadlock_Alert',
                                'MSSQL_Error_Count_Customer_Defined',
                                'MSSQL_Server_Memory_Used',
                                'MSSQL_CPU_Percent_Busy' )
      and c1.comp_id = m.comp_id
      and c1.comptyp_cd = 'CTW_INSTANCE'
      and c2.comp_id    =  c1.comp_corr_id
      and c2.comptyp_cd in ( 'CTW_HOST', 'IP_HOST' )
    GROUP BY m.msmttyp_id, c1.comp_id, c2.comp_id,
             m.comp_id, timestamp (m.msmt_strt_dt,m.msmt_strt_tm)
;
-- confirm that the insertion of the facts has succeeded
-- insert a row in the TWG.EXTRACT_LOG
insert into twg.extract_log
   select ec.extctl_source as extlog_source,
          ec.extctl_target as extlog_target,
          current timestamp as extlog_done_dttm,
          ec.extctl_from_rawseq as extlog_from_rawseq,
          ec.extctl_to_rawseq as extlog_to_rawseq,
          ec.extctl_from_intseq as extlog_from_intseq,
          ec.extctl_to_intseq as extlog_to_intseq,
          ec.extctl_from_dttm as extlog_from_dttm,
          ec.extctl_to_dttm as extlog_to_dttm
     from TWG.Extract_control ec
    where ec.extctl_source = 'TWG.MSMT'
      and ec.extctl_target = 'CTW.STG_F_SRVPERF_HOUR'
;
--#EXECUTE_AT_TARGET
insert into CTW.F_SRVPERF_HOUR
   select * from CTW.STG_F_SRVPERF_HOUR;
