#!/bin/sh
######################################################################
#
# Tivoli Enterprise Data Warehouse, v 1.1.0
# (C) Copyright IBM Corp. 2002.  All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
#
#
#######################################################################
#
# File Information: ctw/v110/misc/ctw_after.sh
#
# Command Line Args:
#       1 = the path and name of the TWH Application config file
#       2 = Application working directory or install base directory
#               $TWH_TOPDIR/apps/ctw/vapp_version
#               (look at install tree)
#
# Required Config File:
#       twh_app_install.cfg
#
# Installation Logs (Default names):
#       A log will be generated for this scirpt called
#       ctw_after.sh.log
#
#
# Required Env Vars:
#       TWH_TOPDIR
#
# Return Codes (Only!):
#       0 = Success
#       255 = Failure
#
# Interpreter Required:
#       NT/2000 = BASH
#       Unix    = SH (Bourne Shell)
#
#
# Message Types:
#       (I) - Informational
#       (W) - Warning
#       (F) - Fatal
#
# Install Steps Required Before this Script Executes:
#        * TWH Core tools components must be successfully installed
#
# Note - Caution needs to be taken for NT paths that have a space.
#        This is a limitation that requires double quoting around all
#        variables that contain a path.  Testing should be done to
#        ensure this script runs with a space in any of the paths
#        that are used.  For example "c:/program files".
#
######################################################################
#
#####################################################
######## Add application code below here ONLY #######
#####################################################

echo "                ** After Script Log **"
echo ""
echo "****************************************"
echo "* Application After Script Start point *"
echo "****************************************"

# Set parms
echo "      Parm 1 = $1"; TWH_CONFIG_FILE="$1"; export TWH_CONFIG_FILE
echo "      Parm 2 = $2"; APP_WORK_DIR="$2"; export APP_WORK_DIR
echo ""

# TWH_TOPDIR needs to always be in the environment
if [ -z "$TWH_TOPDIR" ]; then
  echo "      (F) Could not locate Env var TWH_TOPDIR"
  exit 255
fi

# Execute startup driver for afterscript
. "$TWH_TOPDIR"/install/bin/twh_core_startup_after.sh
exec_startup_driver;

################
# Main section #
################

#####################################
## Stop adding application code #####
#####################################
exec_core_after;                # DO NOT MOVE OR REMOVE!


echo ""
echo "==> Completed executing application after script"
exit 0
